//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[CommonShantenArgsValidationException](index.md)/[args](args.md)

# args

[common]\
val [args](args.md): [CommonShantenArgs](../-common-shanten-args/index.md)
